html, body {
    --bar-background-color: rgba(112, 133, 100, 0.61);
    height: 100%;
    margin: 0;
    padding: 0;
}
body #everything-wrapper {
    width: 100%;
    height: 100vh;
    display: grid;
    grid-template-rows: auto 1fr;
    overflow: hidden;
    box-sizing: border-box;
    margin: 0;
    padding: 0;
}
#everything-wrapper #main-content {
    padding: 10px;
    overflow-y: auto;
}

#everything-wrapper #main-content.enabled.showing {
    border: 2px solid red;
}

#everything-wrapper #main-content.disabled.showing {
    border: 2px solid var(--bar-background-color, rgba(112, 133, 100, 0.61));
}


#everything-wrapper #mimicry-wrapper {
    display: flex;
    flex-direction: column;
    background-color: var(--bar-background-color, rgba(112, 133, 100, 0.61));
    padding: 5px;
    gap: 5px;
}

#mimicry-wrapper div p {
    margin: 0;
}

#mimicry-wrapper .mimicry-main-bar {
    display: flex;
    width: 100%;
    justify-content: space-between;
}

#mimicry-wrapper .mimicry-secondary-bar {
    width: 100%;
}

#mimicry-wrapper .mimicry-secondary-bar form {
    flex-grow: 1;
}

#mimicry-wrapper .mimicry-secondary-bar, #mimicry-wrapper .mimicry-secondary-bar form {
    display: flex;
    gap: 5px;
    justify-content: space-between;
}

#mimicry-wrapper .mimicry-secondary-bar form li {
    display: flex;
    gap: 5px;
    list-style-type: none;
}

#mimicry-wrapper.collapsed .mimicry-secondary-bar {
    display: none;
}