<html lang="en">
    <body>
        <p>Hello, <strong>{{ simulated_user.username }}</strong>,</p>
        <p>Your account was accessed for simulation by <strong>{{ real_user.username }}</strong> on {{ timestamp }}. If you did not expect this, please contact the support team.</p>
        <p>Regards,</p>
        <p>Your Team</p>
    </body>
</html>
